### Download

- Current version: {{ release }}

### Install

- This release:
  `easy_install nose=={{ release }}`
- Development (unstable):
  `easy_install nose==dev`

### Community

- Announcement list
  - Sign up to receive email announcements of new releases
- Users' discussion list
  - Talk about using nose. Get help. Give help!
- TIP list
  - The Testing In Python list features wide-ranging discussions of all topics of interest to python testers.

### Tracker

- Report bugs, request features, wik the wiki, browse source.

### Other links

- py.test
- setuptools

### Older versions

- nose 0.10, the previous major release.
- nose 0.9.3, a very old version that you shouldn't use.